@@ -30,7 +30,7 @@ use overload
     'cmp'  => \&pv_scmp,
     'bool' => \&pv_bool;
 
-our $VERSION = 1.0007;
+our $VERSION = 1.0008;
 
 our $StrictTypes    = 0; # throws errors on unknown units
 our $PrintPrecision = 2; 
@@ -374,8 +374,24 @@ sub pv_print {
 
     if( $u->{unit} == 1 ) {
         $u = "";
+
     } else {
         $u = " $u";
+
+        # XXX: evil hack
+        # Attempt to impose alphabetical ordering 
+        # on kg*m/s vs m*kg/s
+        # (this will only catch simple cases)
+        my @to_fix;
+        while($u =~ m/\b(\w+\*\w+)\b/g) {
+            my $orig = $1;
+            my @s = split m/\*/, $orig;
+            my $fixed = join('*', sort @s);
+            push @to_fix, [quotemeta($orig) => $fixed] if $orig ne $fixed;
+        }
+
+        $u =~ s/$_->[0]/$_->[1]/ for @to_fix;
+
         if( $v != 1 ) {
             $u =~ s/\b$_->[0]\b/$_->[1]/sg for @AUTO_PLURALS;
         }
